@@ -53,10 +53,6 @@ class PillowTestCase(unittest.TestCase):
         # holds last result object passed to run method:
         self.currentResult = None
 
-    # Nicer output for --verbose
-    def __str__(self):
-        return self.__class__.__name__ + "." + self._testMethodName
-
     def run(self, result=None):
         self.currentResult = result  # remember result for use later
         unittest.TestCase.run(self, result)  # call superclass run method
@@ -84,7 +80,7 @@ class PillowTestCase(unittest.TestCase):
             self.assertTrue(
                 all(x == y for x, y in zip(a, b)),
                 msg or "got %s, expected %s" % (a, b))
-        except:
+        except Exception:
             self.assertEqual(a, b, msg)
 
     def assert_image(self, im, mode, size, msg=None):
@@ -110,7 +106,7 @@ class PillowTestCase(unittest.TestCase):
                 try:
                     url = test_image_results.upload(a, b)
                     logger.error("Url for test images: %s" % url)
-                except Exception as msg:
+                except Exception:
                     pass
 
             self.fail(msg or "got different content")
@@ -149,7 +145,7 @@ class PillowTestCase(unittest.TestCase):
                 try:
                     url = test_image_results.upload(a, b)
                     logger.error("Url for test images: %s" % url)
-                except:
+                except Exception:
                     pass
             raise e
 
@@ -163,7 +159,6 @@ class PillowTestCase(unittest.TestCase):
     def assert_warning(self, warn_class, func, *args, **kwargs):
         import warnings
 
-        result = None
         with warnings.catch_warnings(record=True) as w:
             # Cause all warnings to always be triggered.
             warnings.simplefilter("always")
@@ -175,7 +170,7 @@ class PillowTestCase(unittest.TestCase):
             if warn_class is None:
                 self.assertEqual(len(w), 0,
                                  "Expected no warnings, got %s" %
-                                 list(v.category for v in w))
+                                 [v.category for v in w])
             else:
                 self.assertGreaterEqual(len(w), 1)
                 found = False
@@ -187,10 +182,10 @@ class PillowTestCase(unittest.TestCase):
         return result
 
     def assert_all_same(self, items, msg=None):
-        self.assertTrue(items.count(items[0]) == len(items), msg)
+        self.assertEqual(items.count(items[0]), len(items), msg)
 
     def assert_not_all_same(self, items, msg=None):
-        self.assertFalse(items.count(items[0]) == len(items), msg)
+        self.assertNotEqual(items.count(items[0]), len(items), msg)
 
     def assert_tuple_approx_equal(self, actuals, targets, threshold, msg):
         """Tests if actuals has values within threshold from targets"""
