@@ -1,8 +1,14 @@
-from helper import unittest, PillowTestCase
+from .helper import unittest, PillowTestCase
 
-from PIL import FpxImagePlugin
+try:
+    from PIL import FpxImagePlugin
+except ImportError:
+    olefile_installed = False
+else:
+    olefile_installed = True
 
 
+@unittest.skipUnless(olefile_installed, "olefile package not installed")
 class TestFileFpx(PillowTestCase):
 
     def test_invalid_file(self):
@@ -15,7 +21,3 @@ class TestFileFpx(PillowTestCase):
         ole_file = "Tests/images/test-ole-file.doc"
         self.assertRaises(SyntaxError,
                           FpxImagePlugin.FpxImageFile, ole_file)
-
-
-if __name__ == '__main__':
-    unittest.main()
