@@ -1,5 +1,5 @@
 from __future__ import print_function
-from helper import unittest, PillowTestCase, hopper
+from .helper import PillowTestCase, hopper
 from PIL import features
 from PIL._util import py3
 
@@ -8,6 +8,7 @@ import io
 import logging
 import itertools
 import os
+import distutils.version
 
 from PIL import Image, TiffImagePlugin, TiffTags
 
@@ -194,7 +195,7 @@ class TestFileLibTiff(LibTiffTestCase):
         im = Image.open('Tests/images/hopper_g4.tif')
         for tag in im.tag_v2:
             try:
-                del(core_items[tag])
+                del core_items[tag]
             except KeyError:
                 pass
 
@@ -204,7 +205,7 @@ class TestFileLibTiff(LibTiffTestCase):
         #     4: "long",
         #     5: "rational",
         #     12: "double",
-        # type: dummy value
+        # Type: dummy value
         values = {2: 'test',
                   3: 1,
                   4: 2**20,
@@ -222,7 +223,7 @@ class TestFileLibTiff(LibTiffTestCase):
                                      for _ in range(info.length))
 
         # Extra samples really doesn't make sense in this application.
-        del(new_ifd[338])
+        del new_ifd[338]
 
         out = self.tempfile("temp.tif")
         TiffImagePlugin.WRITE_LIBTIFF = True
@@ -231,6 +232,53 @@ class TestFileLibTiff(LibTiffTestCase):
 
         TiffImagePlugin.WRITE_LIBTIFF = False
 
+    def test_custom_metadata(self):
+        custom = {
+            37000: [4, TiffTags.SHORT],
+            37001: [4.2, TiffTags.RATIONAL],
+            37002: ['custom tag value', TiffTags.ASCII],
+            37003: [u'custom tag value', TiffTags.ASCII],
+            37004: [b'custom tag value', TiffTags.BYTE]
+        }
+
+        libtiff_version = TiffImagePlugin._libtiff_version()
+
+        libtiffs = [False]
+        if distutils.version.StrictVersion(libtiff_version) >= \
+           distutils.version.StrictVersion("4.0"):
+            libtiffs.append(True)
+
+        for libtiff in libtiffs:
+            TiffImagePlugin.WRITE_LIBTIFF = libtiff
+
+            def check_tags(tiffinfo):
+                im = hopper()
+
+                out = self.tempfile("temp.tif")
+                im.save(out, tiffinfo=tiffinfo)
+
+                reloaded = Image.open(out)
+                for tag, value in tiffinfo.items():
+                    reloaded_value = reloaded.tag_v2[tag]
+                    if isinstance(reloaded_value, TiffImagePlugin.IFDRational):
+                        reloaded_value = float(reloaded_value)
+
+                    if libtiff and isinstance(value, bytes):
+                        value = value.decode()
+
+                    self.assertEqual(reloaded_value, value)
+
+            # Test with types
+            ifd = TiffImagePlugin.ImageFileDirectory_v2()
+            for tag, tagdata in custom.items():
+                ifd[tag] = tagdata[0]
+                ifd.tagtype[tag] = tagdata[1]
+            check_tags(ifd)
+
+            # Test without types
+            check_tags({tag: tagdata[0] for tag, tagdata in custom.items()})
+        TiffImagePlugin.WRITE_LIBTIFF = False
+
     def test_int_dpi(self):
         # issue #1765
         im = hopper('RGB')
@@ -415,7 +463,7 @@ class TestFileLibTiff(LibTiffTestCase):
         im = Image.open('Tests/images/multipage.tiff')
         frames = im.n_frames
         self.assertEqual(frames, 3)
-        for idx in range(frames):
+        for _ in range(frames):
             im.seek(0)
             # Should not raise ValueError: I/O operation on closed file
             im.load()
@@ -545,11 +593,11 @@ class TestFileLibTiff(LibTiffTestCase):
     def test_read_icc(self):
         with Image.open("Tests/images/hopper.iccprofile.tif") as img:
             icc = img.info.get('icc_profile')
-            self.assertNotEqual(icc, None)
+            self.assertIsNotNone(icc)
         TiffImagePlugin.READ_LIBTIFF = True
         with Image.open("Tests/images/hopper.iccprofile.tif") as img:
             icc_libtiff = img.info.get('icc_profile')
-            self.assertNotEqual(icc_libtiff, None)
+            self.assertIsNotNone(icc_libtiff)
         TiffImagePlugin.READ_LIBTIFF = False
         self.assertEqual(icc, icc_libtiff)
 
@@ -669,7 +717,9 @@ class TestFileLibTiff(LibTiffTestCase):
 
         self.assert_image_similar_tofile(im, "Tests/images/flower.jpg", 0.5)
 
+    def test_old_style_jpeg(self):
+        infile = "Tests/images/old-style-jpeg-compression.tif"
+        im = Image.open(infile)
 
-
-if __name__ == '__main__':
-    unittest.main()
+        self.assert_image_equal_tofile(im,
+                                       "Tests/images/old-style-jpeg-compression.png")
