@@ -1,4 +1,4 @@
-from helper import unittest, PillowTestCase, hopper
+from .helper import PillowTestCase, hopper
 
 from PIL import Image
 
@@ -36,7 +36,3 @@ class TestFileWebpLossless(PillowTestCase):
         image.getdata()
 
         self.assert_image_equal(image, hopper(self.rgb_mode))
-
-
-if __name__ == '__main__':
-    unittest.main()
