@@ -1,5 +1,5 @@
 from __future__ import division
-from helper import unittest, PillowLeakTestCase
+from .helper import unittest, PillowLeakTestCase
 import sys
 from PIL import Image, features, ImageDraw, ImageFont
 
@@ -16,7 +16,8 @@ class TestTTypeFontLeak(PillowLeakTestCase):
         self._test_leak(lambda: draw.text((0, 0), "some text "*1024,  # ~10k
                                           font=font, fill="black"))
 
-    @unittest.skipIf(not features.check('freetype2'), "Test requires freetype2")
+    @unittest.skipIf(not features.check('freetype2'),
+                     "Test requires freetype2")
     def test_leak(self):
         ttype = ImageFont.truetype('Tests/fonts/FreeMono.ttf', 20)
         self._test_font(ttype)
@@ -30,7 +31,3 @@ class TestDefaultFontLeak(TestTTypeFontLeak):
     def test_leak(self):
         default_font = ImageFont.load_default()
         self._test_font(default_font)
-
-
-if __name__ == '__main__':
-    unittest.main()
