@@ -1,8 +1,10 @@
-from helper import unittest, PillowTestCase, hopper
+from .helper import unittest, PillowTestCase, hopper
 
 from PIL import Image
 from PIL._util import py3
 import os
+import sys
+import shutil
 
 
 class TestImage(PillowTestCase):
@@ -56,7 +58,7 @@ class TestImage(PillowTestCase):
         self.assertEqual(im.width, 1)
         self.assertEqual(im.height, 2)
 
-        with self.assertRaises(AttributeError) as e:
+        with self.assertRaises(AttributeError):
             im.size = (3, 4)
 
     def test_invalid_image(self):
@@ -121,6 +123,16 @@ class TestImage(PillowTestCase):
         im.paste(0, (0, 0, 100, 100))
         self.assertFalse(im.readonly)
 
+    @unittest.skipIf(sys.platform.startswith('win32'),
+                     "Test requires opening tempfile twice")
+    def test_readonly_save(self):
+        temp_file = self.tempfile("temp.bmp")
+        shutil.copy("Tests/images/rgb32bf-rgba.bmp", temp_file)
+
+        im = Image.open(temp_file)
+        self.assertTrue(im.readonly)
+        im.save(temp_file)
+
     def test_dump(self):
         im = Image.new("L", (10, 10))
         im._dump(self.tempfile("temp_L.ppm"))
@@ -139,7 +151,6 @@ class TestImage(PillowTestCase):
         # Act/Assert
         # Shouldn't cause AttributeError (#774)
         self.assertFalse(item is None)
-        self.assertFalse(item == None)
         self.assertFalse(item == num)
 
     def test_expand_x(self):
@@ -286,9 +297,9 @@ class TestImage(PillowTestCase):
                           source.alpha_composite, over, (0, 0),
                           "invalid destination")
         self.assertRaises(ValueError,
-                          source.alpha_composite, over, (0))
+                          source.alpha_composite, over, 0)
         self.assertRaises(ValueError,
-                          source.alpha_composite, over, (0, 0), (0))
+                          source.alpha_composite, over, (0, 0), 0)
         self.assertRaises(ValueError,
                           source.alpha_composite, over, (0, -1))
         self.assertRaises(ValueError,
@@ -516,13 +527,23 @@ class TestImage(PillowTestCase):
                 self.assertEqual(new_im.palette.tobytes(),
                                  palette_result.tobytes())
             else:
-                self.assertEqual(new_im.palette, None)
+                self.assertIsNone(new_im.palette)
 
         _make_new(im, im_p, im_p.palette)
         _make_new(im_p, im, None)
         _make_new(im, blank_p, ImagePalette.ImagePalette())
         _make_new(im, blank_pa, ImagePalette.ImagePalette())
 
+    def test_p_from_rgb_rgba(self):
+        for mode, color in [
+            ("RGB", '#DDEEFF'),
+            ("RGB", (221, 238, 255)),
+            ("RGBA", (221, 238, 255, 255))
+        ]:
+            im = Image.new("P", (100, 100), color)
+            expected = Image.new(mode, (100, 100), color)
+            self.assert_image_equal(im.convert(mode), expected)
+
     def test_no_resource_warning_on_save(self):
         # https://github.com/python-pillow/Pillow/issues/835
         # Arrange
@@ -533,6 +554,18 @@ class TestImage(PillowTestCase):
         with Image.open(test_file) as im:
             self.assert_warning(None, im.save, temp_file)
 
+    def test_load_on_nonexclusive_multiframe(self):
+        with open("Tests/images/frozenpond.mpo", "rb") as fp:
+            def act(fp):
+                im = Image.open(fp)
+                im.load()
+            act(fp)
+
+            with Image.open(fp) as im:
+                im.load()
+
+            self.assertFalse(fp.closed)
+
 
 class MockEncoder(object):
     pass
@@ -561,7 +594,3 @@ class TestRegistry(PillowTestCase):
                                                       'DoesNotExist',
                                                       ('args',),
                                                       extra=('extra',))
-
-
-if __name__ == '__main__':
-    unittest.main()
