@@ -1,4 +1,6 @@
-from helper import unittest, PillowTestCase, hopper
+from .helper import PillowTestCase, hopper
+
+from PIL import Image
 
 import copy
 
@@ -33,7 +35,8 @@ class TestImageCopy(PillowTestCase):
             self.assertEqual(out.mode, im.mode)
             self.assertEqual(out.size, croppedSize)
 
-if __name__ == '__main__':
-    unittest.main()
-
-# End of file
+    def test_copy_zero(self):
+        im = Image.new('RGB', (0, 0))
+        out = im.copy()
+        self.assertEqual(out.mode, im.mode)
+        self.assertEqual(out.size, im.size)
