@@ -1,4 +1,4 @@
-from helper import unittest, PillowTestCase, hopper
+from .helper import PillowTestCase, hopper
 
 from PIL import Image
 
@@ -27,19 +27,20 @@ class TestImageQuantize(PillowTestCase):
                 raise
         self.assert_image(converted, 'P', converted.size)
         self.assert_image_similar(converted.convert('RGB'), image, 15)
-        assert len(converted.getcolors()) == 100
+        self.assertEqual(len(converted.getcolors()), 100)
 
     def test_octree_quantize(self):
         image = hopper()
         converted = image.quantize(100, Image.FASTOCTREE)
         self.assert_image(converted, 'P', converted.size)
         self.assert_image_similar(converted.convert('RGB'), image, 20)
-        assert len(converted.getcolors()) == 100
+        self.assertEqual(len(converted.getcolors()), 100)
 
     def test_rgba_quantize(self):
         image = hopper('RGBA')
-        image.quantize()
-        self.assertRaises(Exception, lambda: image.quantize(method=0))
+        self.assertRaises(ValueError, image.quantize, method=0)
+
+        self.assertEqual(image.quantize().convert().mode, "RGBA")
 
     def test_quantize(self):
         image = Image.open('Tests/images/caption_6_33_22.png').convert('RGB')
@@ -47,8 +48,18 @@ class TestImageQuantize(PillowTestCase):
         self.assert_image(converted, 'P', converted.size)
         self.assert_image_similar(converted.convert('RGB'), image, 1)
 
+    def test_quantize_no_dither(self):
+        image = hopper()
+        palette = Image.open('Tests/images/caption_6_33_22.png').convert('P')
 
-if __name__ == '__main__':
-    unittest.main()
+        converted = image.quantize(dither=0, palette=palette)
+        self.assert_image(converted, 'P', converted.size)
 
-# End of file
+    def test_quantize_dither_diff(self):
+        image = hopper()
+        palette = Image.open('Tests/images/caption_6_33_22.png').convert('P')
+
+        dither = image.quantize(dither=1, palette=palette)
+        nodither = image.quantize(dither=0, palette=palette)
+
+        self.assertNotEqual(dither.tobytes(), nodither.tobytes())
