@@ -1,6 +1,4 @@
-from __future__ import print_function
-
-from helper import unittest, PillowTestCase, hopper
+from .helper import PillowTestCase, hopper
 
 from PIL import TiffImagePlugin, Image
 from PIL.TiffImagePlugin import IFDRational
@@ -32,14 +30,14 @@ class Test_IFDRational(PillowTestCase):
         self._test_equal(1, 2, IFDRational(1, 2))
 
     def test_nonetype(self):
-        " Fails if the _delegate function doesn't return a valid function"
+        # Fails if the _delegate function doesn't return a valid function
 
         xres = IFDRational(72)
         yres = IFDRational(72)
-        self.assertTrue(xres._val is not None)
-        self.assertTrue(xres.numerator is not None)
-        self.assertTrue(xres.denominator is not None)
-        self.assertTrue(yres._val is not None)
+        self.assertIsNotNone(xres._val)
+        self.assertIsNotNone(xres.numerator)
+        self.assertIsNotNone(xres.denominator)
+        self.assertIsNotNone(yres._val)
 
         self.assertTrue(xres and 1)
         self.assertTrue(xres and yres)
@@ -60,6 +58,3 @@ class Test_IFDRational(PillowTestCase):
             reloaded = Image.open(out)
             self.assertEqual(float(IFDRational(301, 1)),
                              float(reloaded.tag_v2[282]))
-
-if __name__ == '__main__':
-    unittest.main()
